
/**********************************************************************************************/
/*School Tables Script.sql*/
/**********************************************************************************************/
/*--------------------------------------------------------------------------------------------
Last Updated Date:	2012.03.19
Last Updated By:	hans.p.halvorsen@hit.no
Description:		School Tables

(C) Hans-Petter Halvorsen
-------------------------------------------------------------------------------------------*/

/*
SCHOOL
CLASS
COURSE
TEACHER
TEACHER_COURSE
STUDENT
STUDENT_COURSE
GRADE
*/

if not exists (select * from dbo.sysobjects where id = object_id(N'[SCHOOL]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [SCHOOL]
(
	[SchoolId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[SchoolName] [varchar](50) NOT NULL UNIQUE,
	[Description] [varchar](1000) NULL,
	[Address] [varchar](50) NULL,
	[Phone] [varchar](50) NULL,
	[PostCode] [varchar](50) NULL,
	[PostAddress] [varchar](50) NULL,
 
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[CLASS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [CLASS]
(
	[ClassId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[SchoolId] [int] NOT NULL FOREIGN KEY REFERENCES [SCHOOL] ([SchoolId]),
	[ClassName] [varchar](50) NOT NULL,
	[Description] [varchar](1000) NULL,
	 
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[COURSE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [COURSE]
(
	[CourseId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[CourseName] [varchar](50) NOT NULL,
	[SchoolId] [int] NOT NULL FOREIGN KEY REFERENCES [SCHOOL] ([SchoolId]),
	[Description] [varchar](1000) NULL,
	 
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[TEACHER]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [TEACHER]
(
	[TeacherId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[SchoolId] [int] NOT NULL FOREIGN KEY REFERENCES [SCHOOL] ([SchoolId]),
	[TeacherName] [varchar](50) NOT NULL,
	[Description] [varchar](1000) NULL,
	 
) 
GO



if not exists (select * from dbo.sysobjects where id = object_id(N'[TEACHER_COURSE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [TEACHER_COURSE]
(
	[TeacherId] [int] NOT NULL FOREIGN KEY REFERENCES [TEACHER] ([TeacherId]),
	[CourseId] [int] NOT NULL FOREIGN KEY REFERENCES [COURSE] ([CourseId]),
		 
) 
GO



if not exists (select * from dbo.sysobjects where id = object_id(N'[STUDENT]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [STUDENT]
(
	[StudentId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[ClassId] [int] NOT NULL FOREIGN KEY REFERENCES [CLASS] ([ClassId]),
	[StudentName] [varchar](100) NOT NULL,
	[StudentNumber] [varchar](20) NOT NULL,
	[TotalGrade] [float] NULL,
	[Address] [varchar](100) NULL,
	[Phone] [varchar](20) NULL,
	[EMail] [varchar](100) NULL,
	 
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[STUDENT_COURSE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [STUDENT_COURSE]
(
	[StudentId] [int] NOT NULL FOREIGN KEY REFERENCES [STUDENT] ([StudentId]),
	[CourseId] [int] NOT NULL FOREIGN KEY REFERENCES [COURSE] ([CourseId]),
		 
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[GRADE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [GRADE]
(
	[GradeId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[StudentId] [int] NOT NULL FOREIGN KEY REFERENCES [STUDENT] ([StudentId]),
	[CourseId] [int] NOT NULL FOREIGN KEY REFERENCES [COURSE] ([CourseId]),
	[Grade] [float] NOT NULL,
	[Comment] [varchar](1000) NULL,
	 
) 
GO

	
/**********************************************************************************************/
/*CourseData.view.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'CourseData' 
	   AND 	  type = 'V')
	DROP VIEW CourseData
GO

CREATE VIEW [CourseData]
AS

SELECT
SCHOOL.SchoolId, 
SCHOOL.SchoolName, 
COURSE.CourseId, 
COURSE.CourseName,
COURSE.Description

FROM
SCHOOL 
INNER JOIN COURSE ON SCHOOL.SchoolId = COURSE.SchoolId 
GO


	
/**********************************************************************************************/
/*StudentData.view.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'StudentData' 
	   AND 	  type = 'V')
	DROP VIEW StudentData
GO

CREATE VIEW [StudentData]
AS

SELECT
SCHOOL.SchoolId, 
SCHOOL.SchoolName, 
CLASS.ClassId, 
CLASS.ClassName, 
COURSE.CourseId, 
COURSE.CourseName,
STUDENT.StudentId, 
STUDENT.StudentName, 
STUDENT.StudentNumber,
GRADE.GradeId,
GRADE.Grade

FROM
SCHOOL 
INNER JOIN CLASS ON SCHOOL.SchoolId = CLASS.SchoolId 
INNER JOIN COURSE ON SCHOOL.SchoolId = COURSE.SchoolId 
INNER JOIN STUDENT ON CLASS.ClassId = STUDENT.ClassId 
INNER JOIN STUDENT_COURSE ON COURSE.CourseId = STUDENT_COURSE.CourseId 
	AND STUDENT.StudentId = STUDENT_COURSE.StudentId 
INNER JOIN GRADE ON COURSE.CourseId = GRADE.CourseId AND STUDENT.StudentId = GRADE.StudentId


GO


	
/**********************************************************************************************/
/*StudentGrade.sp.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'StudentGrade' 
	   AND 	  type = 'P')
	DROP PROCEDURE StudentGrade
GO

CREATE PROCEDURE StudentGrade
@Student varchar(50),
@Course varchar(10),
@Grade varchar(1)
 
AS

DECLARE
@StudentId int,
@CourseId int

select StudentId from STUDENT where StudentName = @Student

select CourseId from COURSE where CourseName = @Course


insert into [GRADE]([StudentId],[CourseId],[Grade]) 
values (@StudentId, @CourseId, @Grade)
	
/**********************************************************************************************/
/*CalcAvgGrade.trigger.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'CalcAvgGrade' 
	   AND 	  type = 'TR')
	DROP TRIGGER CalgAvgGrade
GO

CREATE TRIGGER CalcAvgGrade ON GRADE
FOR UPDATE, INSERT, DELETE

AS
DECLARE
@StudentId int,
@AvgGrade float


select @StudentId = StudentId from INSERTED


select @AvgGrade = AVG(Grade) from GRADE where StudentId = @StudentId


update STUDENT set TotalGrade = @AvgGrade where StudentId = @StudentId

GO

	
/**********************************************************************************************/
/*Insert Data into Tables.sql*/
/**********************************************************************************************/
/*--------------------------------------------------------------------------------------------
Last Updated Date:	2011.03.24
Last Updated By:	hans.p.halvorsen@hit.no
Description:		Lab Work - Insert Data into School Tables

(C) Hans-Petter Halvorsen
-------------------------------------------------------------------------------------------*/

/*
SCHOOL
CLASS
COURSE
STUDENT
STUDENT_COURSE
GRADE
*/


--SCHOOL ----------------------------------
INSERT INTO [SCHOOL]([SchoolName]) 
VALUES ('TUC')
GO

INSERT INTO [SCHOOL]([SchoolName]) 
VALUES ('NTNU')
GO

INSERT INTO [SCHOOL]([SchoolName]) 
VALUES ('MIT')
GO


--CLASS ----------------------------------
INSERT INTO [CLASS]([SchoolId],[ClassName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'SCE1')
GO

INSERT INTO [CLASS]([SchoolId],[ClassName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'SCE2')
GO

INSERT INTO [CLASS]([SchoolId],[ClassName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'PT1')
GO

INSERT INTO [CLASS]([SchoolId],[ClassName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'PT2')
GO



--COURSE ----------------------------------
INSERT INTO [COURSE]([SchoolId],[CourseName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'SCE2006')
GO

INSERT INTO [COURSE]([SchoolId],[CourseName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'SCE1106')
GO

INSERT INTO [COURSE]([SchoolId],[CourseName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'SCE4206')
GO

INSERT INTO [COURSE]([SchoolId],[CourseName]) 
VALUES ((select SchoolId from SCHOOL where SchoolName='TUC'), 'SCE4106')
GO



--STUDENT ----------------------------------
INSERT INTO [STUDENT]([ClassId],[StudentName],[StudentNumber]) 
VALUES ((select ClassId from CLASS where ClassName='SCE1'), 'John Cleese', '1111')
GO

INSERT INTO [STUDENT]([ClassId],[StudentName],[StudentNumber]) 
VALUES ((select ClassId from CLASS where ClassName='SCE1'), 'Jens Stoltenberg', '2222')
GO

INSERT INTO [STUDENT]([ClassId],[StudentName],[StudentNumber]) 
VALUES ((select ClassId from CLASS where ClassName='SCE2'), 'Barak Obama', '3333')
GO

INSERT INTO [STUDENT]([ClassId],[StudentName],[StudentNumber]) 
VALUES ((select ClassId from CLASS where ClassName='SCE2'), 'Kurt Nilsen', '4444')
GO

	

--STUDENT_COURSE ----------------------------------
INSERT INTO [STUDENT_COURSE]([StudentId], [CourseId]) 
VALUES ((select StudentId from STUDENT where StudentNumber='1111'),(select CourseId from COURSE where CourseName='SCE2006'))
GO

INSERT INTO [STUDENT_COURSE]([StudentId], [CourseId]) 
VALUES ((select StudentId from STUDENT where StudentNumber='2222'),(select CourseId from COURSE where CourseName='SCE2006'))
GO

INSERT INTO [STUDENT_COURSE]([StudentId], [CourseId]) 
VALUES ((select StudentId from STUDENT where StudentNumber='3333'),(select CourseId from COURSE where CourseName='SCE4206'))
GO

INSERT INTO [STUDENT_COURSE]([StudentId], [CourseId]) 
VALUES ((select StudentId from STUDENT where StudentNumber='4444'),(select CourseId from COURSE where CourseName='SCE4206'))
GO



--GRADE ----------------------------------
INSERT INTO [GRADE]([StudentId], [CourseId], [Grade]) 
VALUES ((select StudentId from STUDENT where StudentNumber='1111'), (select CourseId from COURSE where CourseName='SCE2006'), 4)
GO

INSERT INTO [GRADE]([StudentId], [CourseId], [Grade]) 
VALUES ((select StudentId from STUDENT where StudentNumber='2222'), (select CourseId from COURSE where CourseName='SCE2006'), 5)
GO

INSERT INTO [GRADE]([StudentId], [CourseId], [Grade]) 
VALUES ((select StudentId from STUDENT where StudentNumber='3333'), (select CourseId from COURSE where CourseName='SCE4206'), 0)
GO

INSERT INTO [GRADE]([StudentId], [CourseId], [Grade]) 
VALUES ((select StudentId from STUDENT where StudentNumber='4444'), (select CourseId from COURSE where CourseName='SCE4206'), 3)
GO










